Package: affycomp
Version: 1.89.0
Title: Graphics Toolbox for Assessment of Affymetrix Expression
        Measures
Author: Rafael A. Irizarry <rafa@ds.dfci.harvard.edu> and Zhijin Wu
        <zwu@stat.brown.edu> with contributions from Simon Cawley
        <simon_cawley@affymetrix.com>
Maintainer: Robert D. Shear <rshear@ds.dfci.harvard.edu>
URL: https://bioconductor.org/packages/affycomp
BugReports: https://github.com/rafalab/affycomp/issues
Depends: R (>= 2.13.0), methods, Biobase (>= 2.3.3)
Suggests: splines, affycompData
Description: The package contains functions that can be used to
        compare expression measures for Affymetrix Oligonucleotide
        Arrays.
License: GPL (>= 2)
biocViews: OneChannel, Microarray, Preprocessing
git_url: https://git.bioconductor.org/packages/affycomp
git_branch: devel
git_last_commit: 958e3fe
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 21:10:22 UTC; biocbuild
